==> tomee-project-7.0.1-source-release.zip: tomee-project-7.0.1/container/openejb-jee/src/main/java/org/apache/openejb/jee/sun/RequestProtection.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.jee.sun;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.CollapsedStringAdapter;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
public class RequestProtection {
    @XmlAttribute(name = "auth-source")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    protected String authSource;
    @XmlAttribute(name = "auth-recipient")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    protected String authRecipient;

    public String getAuthSource() {
        return authSource;
    }

    public void setAuthSource(final String value) {
        this.authSource = value;
    }

    public String getAuthRecipient() {
        return authRecipient;
    }

    public void setAuthRecipient(final String value) {
        this.authRecipient = value;
    }
}

==> tomee-project-10.1.3-source-release.zip: tomee-project-10.1.3/container/openejb-jee/src/main/java/org/apache/openejb/jee/sun/RequestProtection.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.jee.sun;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;
import jakarta.xml.bind.annotation.adapters.CollapsedStringAdapter;
import jakarta.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "")
public class RequestProtection {
    @XmlAttribute(name = "auth-source")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    protected String authSource;
    @XmlAttribute(name = "auth-recipient")
    @XmlJavaTypeAdapter(CollapsedStringAdapter.class)
    protected String authRecipient;

    public String getAuthSource() {
        return authSource;
    }

    public void setAuthSource(final String value) {
        this.authSource = value;
    }

    public String getAuthRecipient() {
        return authRecipient;
    }

    public void setAuthRecipient(final String value) {
        this.authRecipient = value;
    }
}
